#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='cjrh_template',
      version='2017.10.17',
      description='Subclass for string.Template: adds placeholders() method. ',
      author='Caleb Hattingh',
      author_email='caleb.hattingh@gmail.com',
      url='https://github.com/cjrh/cjrh_template',
      py_modules=['cjrh_template'],
     )
